#
# spec file for package deepin-calendar
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name dde-calendar
%define gtest_version    %(rpm -q --queryformat '%%{VERSION}' gtest)
%if 0%{?is_opensuse}
    %define  distribution  openSUSE-Edition
%else
    %define  distribution  SUSE-Edition
%endif

Name:           deepin-calendar
Version:        5.8.30
Release:        2.2
Summary:        A calendar application for Deepin Desktop
License:        GPL-3.0-or-later
Group:          Productivity/Office/Organizers
URL:            https://github.com/linuxdeepin/dde-calendar
Source0:        https://github.com/linuxdeepin/dde-calendar/archive/%{version}/%{_name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix-hardcode-path.patch hillwood@opensuse.org
# https://github.com/linuxdeepin/dde-calendar/pull/49
Patch0:         fix-hardcode-path.patch
# PATCH-FIX-UPSTREAM - https://github.com/linuxdeepin/dde-calendar/issues/50#issuecomment-979196208
Patch1:         fix-stub.h.patch
BuildRequires:  deepin-gettext-tools
BuildRequires:  desktop-file-utils
%ifarch ppc ppc64 ppc64le s390 s390x
BuildRequires:  deepin-desktop-base
%else
BuildRequires:  deepin-manual
%endif
BuildRequires:  fdupes
BuildRequires:  gtest
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(dframeworkdbus)
BuildRequires:  pkgconfig(dtkgui)
BuildRequires:  pkgconfig(dtkwidget)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The deepin-calendar is a calendar for Deepin Desktop Environment.

%lang_package

%prep
%autosetup -p1 -n %{_name}-%{version}
sed -i 's/lrelease)/lrelease-qt5)/g' CMakeLists.txt
sed -i 's/lupdate)/lupdate-qt5)/g' CMakeLists.txt
sed -i '/<QQueue>/a #include <QMouseEvent>' calendar-client/src/widget/dayWidget/daymonthview.cpp \
calendar-client/src/widget/weekWidget/weekheadview.cpp
sed -i '/<QStylePainter>/a #include <QMouseEvent>' calendar-client/src/widget/schedulesearchview.cpp
sed -i '/include <QJsonObject>/a #include <QMouseEvent>' calendar-client/src/view/draginfographicsview.cpp
sed -i '/include <QPainter>/a #include <QMouseEvent>' schedule-plugin/src/widget/itemwidget.h \
       schedule-plugin/src/widget/modifyscheduleitem.h

# Not included in https://github.com/linuxdeepin/dde-calendar/pull/30 yet
sed -i '/include <QPainter>/a #include <QPainterPath>' calendar-client/src/widget/schedulesearchview.cpp \
       calendar-client/src/widget/dayWidget/daymonthview.cpp \
       calendar-client/src/widget/weekWidget/weekheadview.cpp \
       calendar-client/src/customWidget/customframe.cpp \
       calendar-client/src/widget/yearWidget/yearview.cpp \
       schedule-plugin/src/widget/modifyscheduleitem.h \
       schedule-plugin/src/widget/itemwidget.h
sed -i '/include <QMessageBox>/a #include <QWheelEvent>' calendar-client/src/widget/yearWidget/yearwindow.cpp
sed -i 's/1.2.2/%{version}/g' calendar-client/CMakeLists.txt
sed -i 's/Exec=dde-calendar/Exec=env QT_QPA_PLATFORMTHEME=deepin dde-calendar/g' \
calendar-client/assets/dde-calendar.desktop
sed -i 's/5.5//g' calendar-client/CMakeLists.txt calendar-service/CMakeLists.txt
%if "%{gtest_version}" >= "1.14.0"
sed -i '/CMAKE_CXX_STANDARD/s|11|14|g' tests/*/CMakeLists.txt
%endif

%build
%cmake -DVERSION=%{version}-%{distribution}
%cmake_build

%install
%cmake_install

install -d %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
install -m0644 calendar-client/assets/resources/icon/%{_name}.svg \
%{buildroot}%{_datadir}/icons/hicolor/scalable/apps

%fdupes %{buildroot}
%suse_update_desktop_file -r %{_name} QT Office Calendar Core

%files
%defattr(-,root,root,-)
%doc README.md
%license LICENSE
%{_bindir}/%{_name}
%{_datadir}/applications/%{_name}.desktop
%{_sysconfdir}/xdg/autostart/%{_name}-service.desktop
%dir %{_prefix}/lib/deepin-daemon
%{_prefix}/lib/deepin-daemon/dde-calendar-service
%{_datadir}/dbus-1/services/*.service
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/%{_name}.svg
%{_datadir}/deepin-manual/manual-assets/application/%{_name}
%dir %{_libdir}/deepin-aiassistant
%dir %{_libdir}/deepin-aiassistant/serivce-plugins
%{_libdir}/deepin-aiassistant/serivce-plugins/libuosschedulex-plugin.so
%{_prefix}/lib/systemd/user/com.dde.calendarserver.calendar.*

%files lang
%defattr(-,root,root,-)
%{_datadir}/%{_name}

%changelog
* Thu Mar 28 2024 Hillwood Yang <hillwood@opensuse.org>
- Fix build on gtest 1.14.0
* Sat Jul  2 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.30
  * Optimmze ui
  * Fix bugs
  * Update translations
* Thu Mar 31 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.29
  * Add a systemd timer
  * Optimize ui
  * Fix bugs
  * Update translations
* Sat Jan 29 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.27
  * Fix bugs
  * Update translations
  * Update documents
* Thu Dec  2 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix build on aarch64:
  * fix-stub.h.patch
* Thu Oct 28 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.16
  * Update manual documents
  * Fix bugs
- Add fix-hardcode-path.patch
* Thu Jul 29 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.12
  * Fix bugs
  * Update translations
* Thu Jun  3 2021 Hillwood Yang <hillwood@opensuse.org>
- Stop owning directories provided by filesystem and other packages
  (every dir should only have one owner) (boo#1184786)
* Sat May  1 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.0.19
  * Add help documents
  * Fix bugs
* Thu Feb  4 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.0.8
  * The new ui design.
* Fri Dec 21 2018 hillwood@opensuse.org
- Update version to 1.2.6
  * add genericName
  * set window title
  * Fix register user scope single instance
  * Fix not refresh day when direct switch month
  * Add acknowledgement link
* Mon Mar 19 2018 hillwood@opensuse.org
- Update version to 1.2.1
  * fix calendar not update current Lunar
  * Fix not update current lunar date with first run
  * Adapt lintian
  * change buttonrelease to buttonpress event
* Fri Dec  1 2017 hillwood@opensuse.org
- Update to 1.1.1
  * Support hidpi
* Mon Nov  6 2017 hillwood@opensuse.org
- Cleanup spec
- Split language packge
- Use %%suse_update_desktop_file
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
